package script

import (
	"context"
	"testing"
)

func runTestScript(t *testing.T, src string, expected float64) {
	s, err := NewScript([]byte(src))
	if err != nil {
		t.Fatalf("NewScript: %v", err)
	}
	m := map[string]int64{
		"test":  10,
		"test2": 2,
	}

	score, err := s.RunIP(context.Background(), "1.2.3.4", m, 3600, nil)
	if err != nil {
		t.Fatalf("runScript: %v", err)
	}
	if score != expected {
		t.Fatalf("bad score, expected %f got %f", expected, score)
	}
}

func TestScript_WithLookup(t *testing.T) {
	runTestScript(t, `
score = counts["test"] / 2 + counts["test2"]
//score = 7
`, 7)
}

func TestScript_FloatScore(t *testing.T) {
	runTestScript(t, `
score = 7.0
`, 7)
}

func TestScript_IntScore(t *testing.T) {
	runTestScript(t, `
score = 7
`, 7)
}

func TestScript_StringScore(t *testing.T) {
	runTestScript(t, `
score = "7"
`, 7)
}
